@@ -37,7 +37,7 @@ void LuaExpression::evaluate()
     session()->enqueueExpression(this);
 }
 
-void LuaExpression::parseError(QString &error)
+void LuaExpression::parseError(const QString &error)
 {
     qDebug() << error;
     setErrorMessage(error);
@@ -53,7 +53,3 @@ void LuaExpression::parseOutput(const QString &output)
     setStatus(Cantor::Expression::Done);
 }
 
-void LuaExpression::interrupt()
-{
-    setStatus(Cantor::Expression::Interrupted);
-}
