@@ -24,10 +24,15 @@ QString TestMaxima::backendName()
     return QLatin1String("maxima");
 }
 
+void TestMaxima::initTestCase() {
+    if (QStandardPaths::findExecutable(QLatin1String("maxima")).isEmpty())
+        QSKIP("Maxima executable not found");
+    BackendTest::initTestCase();
+}
 
 void TestMaxima::testSimpleCommand()
 {
-    auto* e=evalExp( QLatin1String("2+2") );
+    auto* e = evalExp( QLatin1String("2+2") );
 
     QVERIFY( e!=nullptr );
     QVERIFY( e->result()!=nullptr );
@@ -51,19 +56,15 @@ void TestMaxima::testMultilineCommand()
 void TestMaxima::testPlot()
 {
     if(QStandardPaths::findExecutable(QLatin1String("gnuplot")).isNull())
-    {
         QSKIP("gnuplot not found, maxima needs it for plotting", SkipSingle);
-    }
 
-    auto* e=evalExp( QLatin1String("plot2d(sin(x), [x, -10,10])") );
+    auto* e = evalExp( QLatin1String("plot2d(sin(x), [x, -10,10])") );
 
     QVERIFY( e!=nullptr );
     QVERIFY( e->result()!=nullptr );
 
-    if(!e->result())
-    {
-        waitForSignal(e, SIGNAL(gotResult()));
-    }
+    if(session()->status() == Cantor::Session::Running)
+        waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
 
     QCOMPARE( e->result()->type(), (int)Cantor::ImageResult::Type );
     QVERIFY( !e->result()->data().isNull() );
@@ -84,8 +85,32 @@ void TestMaxima::testPlotMultiline()
     QVERIFY(e != nullptr);
     QVERIFY(e->result() != nullptr);
 
-    if(!e->result())
-        waitForSignal(e, SIGNAL(gotResult()));
+    if(session()->status() == Cantor::Session::Running)
+        waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
+
+    QCOMPARE(e->result()->type(), (int)Cantor::ImageResult::Type);
+    QVERIFY(!e->result()->data().isNull());
+    QVERIFY(e->errorMessage().isNull());
+}
+
+void TestMaxima::testPlotWithWhitespaces()
+{
+    if(QStandardPaths::findExecutable(QLatin1String("gnuplot")).isNull())
+        QSKIP("gnuplot not found, maxima needs it for plotting", SkipSingle);
+
+    auto* e = evalExp(QLatin1String(
+                "\n"
+                "plot2d (x^2-y^3+3*y=2,\n"
+                "[x,-2.5,2.5],\n"
+                "[y,-2.5,2.5])"
+                "\n"
+    ));
+
+    QVERIFY(e != nullptr);
+    QVERIFY(e->result() != nullptr);
+
+    if(session()->status() == Cantor::Session::Running)
+        waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
 
     QCOMPARE(e->result()->type(), (int)Cantor::ImageResult::Type);
     QVERIFY(!e->result()->data().isNull());
@@ -95,18 +120,16 @@ void TestMaxima::testPlotMultiline()
 void TestMaxima::testPlotWithAnotherTextResults()
 {
     if(QStandardPaths::findExecutable(QLatin1String("gnuplot")).isNull())
-    {
         QSKIP("gnuplot not found, maxima needs it for plotting", SkipSingle);
-    }
 
-    auto* e=evalExp( QLatin1String(
+    auto* e = evalExp( QLatin1String(
         "2*2; \n"
         "plot2d(sin(x), [x, -10,10]); \n"
         "4*4;"
     ));
 
-    if (e->results().at(1)->type() == Cantor::TextResult::Type)
-        waitForSignal(e, SIGNAL(resultReplaced));
+    if(session()->status() == Cantor::Session::Running)
+        waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
 
     QVERIFY( e!=nullptr );
     QVERIFY( e->errorMessage().isNull() );
@@ -123,9 +146,7 @@ void TestMaxima::testPlotWithAnotherTextResults()
 void TestMaxima::testDraw()
 {
     if(QStandardPaths::findExecutable(QLatin1String("gnuplot")).isNull())
-    {
         QSKIP("gnuplot not found, maxima needs it for plotting", SkipSingle);
-    }
 
     auto* e = evalExp( QLatin1String("draw3d(explicit(x^2+y^2,x,-1,1,y,-1,1))") );
 
@@ -133,9 +154,7 @@ void TestMaxima::testDraw()
     QVERIFY(e->result() != nullptr);
 
     if(!e->result())
-    {
         waitForSignal(e, SIGNAL(gotResult()));
-    }
 
     QCOMPARE( e->result()->type(), (int)Cantor::ImageResult::Type );
     QVERIFY( !e->result()->data().isNull() );
@@ -180,9 +199,7 @@ void TestMaxima::testDrawMultiline()
 void TestMaxima::testDrawWithAnotherTextResults()
 {
     if(QStandardPaths::findExecutable(QLatin1String("gnuplot")).isNull())
-    {
         QSKIP("gnuplot not found, maxima needs it for plotting", SkipSingle);
-    }
 
     auto* e = evalExp( QLatin1String(
         "2*2; \n"
@@ -207,10 +224,12 @@ void TestMaxima::testDrawWithAnotherTextResults()
 
 void TestMaxima::testInvalidSyntax()
 {
-    auto* e=evalExp( QLatin1String("2+2*(") );
+    auto* e = evalExp( QLatin1String("2+2*(") );
 
     QVERIFY( e!=nullptr );
     QVERIFY( e->status()==Cantor::Expression::Error );
+    QVERIFY( !e->errorMessage().isNull() );
+    QCOMPARE(e->results().size(), 0);
 }
 
 void TestMaxima::testWarning01()
@@ -251,7 +270,7 @@ void TestMaxima::testWarning02()
 
 void TestMaxima::testExprNumbering()
 {
-    auto* e=evalExp( QLatin1String("kill(labels)") ); //first reset the labels
+    auto* e = evalExp( QLatin1String("kill(labels)") ); //first reset the labels
 
     e=evalExp( QLatin1String("2+2") );
     QVERIFY( e!=nullptr );
@@ -269,9 +288,9 @@ void TestMaxima::testCommandQueue()
     //only wait for the last Expression to return, so the queue gets
     //actually filled
 
-    auto* e1=session()->evaluateExpression(QLatin1String("0+1"));
-    auto* e2=session()->evaluateExpression(QLatin1String("1+1"));
-    auto* e3=evalExp(QLatin1String("1+2"));
+    auto* e1 = session()->evaluateExpression(QLatin1String("0+1"));
+    auto* e2 = session()->evaluateExpression(QLatin1String("1+1"));
+    auto* e3 = evalExp(QLatin1String("1+2"));
 
     QVERIFY(e1!=nullptr);
     QVERIFY(e2!=nullptr);
@@ -288,7 +307,7 @@ void TestMaxima::testCommandQueue()
 
 void TestMaxima::testSimpleExpressionWithComment()
 {
-    auto* e=evalExp(QLatin1String("/*this is a comment*/2+2"));
+    auto* e = evalExp(QLatin1String("/*this is a comment*/2+2"));
     QVERIFY(e!=nullptr);
     QVERIFY(e->result()!=nullptr);
 
@@ -297,14 +316,14 @@ void TestMaxima::testSimpleExpressionWithComment()
 
 void TestMaxima::testCommentExpression()
 {
-    auto* e=evalExp(QLatin1String("/*this is a comment*/"));
+    auto* e = evalExp(QLatin1String("/*this is a comment*/"));
     QVERIFY(e!=nullptr);
     QVERIFY(e->result()==nullptr||e->result()->data().toString().isEmpty());
 }
 
 void TestMaxima::testNestedComment()
 {
-    auto* e=evalExp(QLatin1String("/*/*this is still a comment*/*/2+2/*still/*a*/comment*//**/"));
+    auto* e = evalExp(QLatin1String("/*/*this is still a comment*/*/2+2/*still/*a*/comment*//**/"));
     QVERIFY(e!=nullptr);
     QVERIFY(e->result()!=nullptr);
 
@@ -313,7 +332,7 @@ void TestMaxima::testNestedComment()
 
 void TestMaxima::testUnmatchedComment()
 {
-    auto* e=evalExp(QLatin1String("/*this comment doesn't end here!"));
+    auto* e = evalExp(QLatin1String("/*this comment doesn't end here!"));
     QVERIFY(e!=nullptr);
     QVERIFY(e->result()==nullptr);
     QVERIFY(e->status()==Cantor::Expression::Error);
@@ -321,12 +340,12 @@ void TestMaxima::testUnmatchedComment()
 
 void TestMaxima::testInvalidAssignment()
 {
-    auto* e=evalExp(QLatin1String("0:a"));
+    auto* e = evalExp(QLatin1String("0:a"));
     QVERIFY(e!=nullptr);
     //QVERIFY(e->result()==0);
     //QVERIFY(e->status()==Cantor::Expression::Error);
 
-    if(session()->status()==Cantor::Session::Running)
+    if(session()->status() == Cantor::Session::Running)
         waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
 
     //make sure we didn't screw up the session
@@ -337,9 +356,31 @@ void TestMaxima::testInvalidAssignment()
     QCOMPARE(cleanOutput(e2->result()->data().toString()), QLatin1String("4"));
 }
 
+void TestMaxima::testHelpRequest()
+{
+    //execute "??print"
+    auto* e = session()->evaluateExpression(QLatin1String("??print"));
+    QVERIFY(e != nullptr);
+
+    //help result will be shown, but maxima still expects further input
+    waitForSignal(e, SIGNAL(needsAdditionalInformation(QString)));
+    QVERIFY(e->status() != Cantor::Expression::Done);
+    QVERIFY(e->results().size() == 1); // one HelpResult showing the possible options for the answer
+
+    //ask for help for the first flag of the print command
+    e->addInformation(QLatin1String("0"));
+
+    //no further input is required, we're done
+    if (e->status() == Cantor::Expression::Computing)
+        waitForSignal(e, SIGNAL(statusChanged(Cantor::Expression::Status)));
+
+    QVERIFY(e->status() == Cantor::Expression::Done);
+    QVERIFY(e->results().size() == 1); // final HelpResult
+}
+
 void TestMaxima::testInformationRequest()
 {
-    auto* e=session()->evaluateExpression(QLatin1String("integrate(x^n,x)"));
+    auto* e = session()->evaluateExpression(QLatin1String("integrate(x^n,x)"));
     QVERIFY(e!=nullptr);
     waitForSignal(e, SIGNAL(needsAdditionalInformation(QString)));
     e->addInformation(QLatin1String("N"));
@@ -352,7 +393,7 @@ void TestMaxima::testInformationRequest()
 
 void TestMaxima::testSyntaxHelp()
 {
-    Cantor::SyntaxHelpObject* help = session()->syntaxHelpFor(QLatin1String("simplify_sum"));
+    auto* help = session()->syntaxHelpFor(QLatin1String("simplify_sum"));
     help->fetchSyntaxHelp();
     waitForSignal(help, SIGNAL(done()));
 
@@ -363,7 +404,7 @@ void TestMaxima::testSyntaxHelp()
 
 void TestMaxima::testCompletion()
 {
-    Cantor::CompletionObject* help = session()->completionFor(QLatin1String("ask"), 3);
+    auto* help = session()->completionFor(QLatin1String("ask"), 3);
     waitForSignal(help, SIGNAL(fetchingDone()));
 
     // Checks all completions for this request
@@ -374,37 +415,13 @@ void TestMaxima::testCompletion()
     QVERIFY(completions.contains(QLatin1String("askexp")));
 }
 
-void TestMaxima::testHelpRequest()
-{
-    //execute "??print"
-    auto* e = session()->evaluateExpression(QLatin1String("??print"));
-    QVERIFY(e != nullptr);
-
-    //help result will be shown, but maxima still expects further input
-    waitForSignal(e, SIGNAL(needsAdditionalInformation(QString)));
-    if (e->status() == Cantor::Expression::Computing)
-        waitForSignal(e, SIGNAL(statusChanged(Cantor::Expression::Status)));
-    QVERIFY(e->status() != Cantor::Expression::Done);
-    QVERIFY(e->results().size() == 1); //two results, the warning and the actual result of the calculation
-
-    //ask for help for the first flag of the print command
-    e->addInformation(QLatin1String("0"));
-
-    //no further input is required, we're done
-    waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
-    if (e->status() == Cantor::Expression::Computing)
-        waitForSignal(e, SIGNAL(statusChanged(Cantor::Expression::Status)));
-    QVERIFY(e->status() == Cantor::Expression::Done);
-    QVERIFY(e->results().size() == 2); //two results, the warning and the actual result of the calculation
-}
-
 void TestMaxima::testTextQuotes()
 {
-    // check simple sting
+    // check simple string
     auto* e1 = evalExp(QLatin1String("t1: \"test string\""));
     QVERIFY(e1 != nullptr);
 
-    if(session()->status()==Cantor::Session::Running)
+    if(session()->status() == Cantor::Session::Running)
         waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
 
     QVERIFY(e1->result() != nullptr);
@@ -415,7 +432,7 @@ void TestMaxima::testTextQuotes()
     auto* e2 = evalExp(QLatin1String("t2: \"this is a \\\"quoted string\\\"\""));
     QVERIFY(e2 != nullptr);
 
-    if(session()->status()==Cantor::Session::Running)
+    if(session()->status() == Cantor::Session::Running)
         waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
 
     QVERIFY(e2->result() != nullptr);
@@ -437,7 +454,7 @@ void TestMaxima::testVariableModel()
     QVERIFY(e3 != nullptr);
     QVERIFY(e4 != nullptr);
 
-    if(session()->status()==Cantor::Session::Running)
+    if(session()->status() == Cantor::Session::Running)
         waitForSignal(session(), SIGNAL(statusChanged(Cantor::Session::Status)));
 
     QCOMPARE(4, model->rowCount());
@@ -505,9 +522,12 @@ void TestMaxima::testLoginLogout()
 
 void TestMaxima::testRestartWhileRunning()
 {
-    auto* e1=session()->evaluateExpression(QLatin1String(":lisp (sleep 5)"));
+    QSKIP("This test is not working yet.", SkipSingle);
+    auto* e1 = session()->evaluateExpression(QLatin1String(":lisp (sleep 5)"));
+    QVERIFY(e1 != nullptr);
 
     session()->logout();
+
     QCOMPARE(e1->status(), Cantor::Expression::Interrupted);
     session()->login();
 
