@@ -19,6 +19,8 @@ class TestMaxima : public BackendTest
   Q_OBJECT
 
 private Q_SLOTS:
+    void initTestCase();
+
     //tests evaluating a simple command
     void testSimpleCommand();
     //tests a command, containing more than 1 line
@@ -29,6 +31,7 @@ private Q_SLOTS:
     //tests doing a plot
     void testPlot();
     void testPlotMultiline();
+    void testPlotWithWhitespaces();
     void testPlotWithAnotherTextResults();
     void testDraw();
     void testDrawMultiline();
